@@ -28,6 +28,7 @@ require 'lib/output'
 require 'lib/details'
 require 'lib/auth'
 require 'getoptlong'
+require 'fileutils'
 
 
 class GeoToad
@@ -36,21 +37,21 @@ class GeoToad
   include Auth
 
   # The version gets inserted by makedist.sh
-  versionID='3.10.2'
+  versionID='3.11.0'
   if versionID !~ /^\d/
     $VERSION = '3.10-CURRENT'
   else
     $VERSION = versionID.dup
   end
 
-  $SLEEP=1
-  $SLOWMODE=350
+  $SLEEP = 1.5
+  $SLOWMODE = 350
 
   def initialize
     output        = Output.new
     $validFormats = output.formatList.sort
     @uin          = Input.new
-    $CACHE_DIR    = findCacheDir
+    $CACHE_DIR    = findCacheDir()
   end
 
 
@@ -70,11 +71,16 @@ class GeoToad
     end
 
     # We need this for the check following
-    @queryType         = @option['queryType'] || 'zipcode'
+    @queryType         = @option['queryType'] || 'location'
     @queryArg          = @option['queryArg'] || nil
 
     # Get this out of the way now.
-    if (! @queryArg) || @option['help'] || (! @option['user']) ||  (! @option['password'])
+    if @option['help']
+      @uin.usage
+      exit
+    end    
+    
+    if (! @option['clearCache']) && ((! @queryArg) || (! @option['user']) || (! @option['password']))
       if (! @queryArg)
         displayError "You forgot to specify a #{@queryType} search argument"
       end
@@ -147,6 +153,13 @@ class GeoToad
     debug "Check complete."
   end
 
+  def clearCacheDirectory
+    puts "* Clearing #{$CACHE_DIR}"
+    FileUtils::remove_dir($CACHE_DIR)
+    puts "* Cleared!"
+    $CACHE_DIR = findCacheDir()
+  end
+    
   ## Make the Initial Query ############################
   def downloadGeocacheList
     displayInfo "Your cache directory is " + $CACHE_DIR
@@ -586,11 +599,15 @@ puts "GeoToad #{$VERSION} (#{RUBY_PLATFORM}-#{RUBY_VERSION})"
 puts "- Report bugs or suggestions at http://code.google.com/p/geotoad/issues/"
 puts "- Please include verbose output (-v) without passwords in the bug report."
 cli = GeoToad.new
-# cli.versionCheck
+#cli.versionCheck
 
 while(1)
   options = cli.getoptions
-  count = cli.downloadGeocacheList
+  if options['clearCache']
+    cli.clearCacheDirectory()
+  end
+  
+  count = cli.downloadGeocacheList()
   if count < 1
     cli.displayError "No caches found in search, exiting early."
   else
