@@ -1,4 +1,4 @@
-# $Id: input.rb 558 2010-01-27 07:31:22Z helixblue $
+# $Id: input.rb 576 2010-04-11 14:52:02Z helixblue $
 
 class Input
   include Common
@@ -46,7 +46,7 @@ class Input
     opts = GetoptLong.new(
       [ "--travelBug",                "-b",    GetoptLong::NO_ARGUMENT ],
       [ "--cacheType",                "-c",    GetoptLong::REQUIRED_ARGUMENT ],
-      [ "--includeDisabled",          "-z",    GetoptLong::NO_ARGUMENT ],
+      [ "--clearCache",                "-C",    GetoptLong::NO_ARGUMENT ],
 
       [ "--difficultyMax",            "-D",        GetoptLong::OPTIONAL_ARGUMENT ],
       [ "--difficultyMin",            "-d",        GetoptLong::OPTIONAL_ARGUMENT ],
@@ -91,7 +91,8 @@ class Input
       [ "--verbose",                    "-v",    GetoptLong::NO_ARGUMENT ],
       [ "--format",                    "-x",        GetoptLong::OPTIONAL_ARGUMENT ],
 
-      [ "--distanceMax",                "-y",        GetoptLong::OPTIONAL_ARGUMENT ]
+      [ "--distanceMax",                "-y",        GetoptLong::OPTIONAL_ARGUMENT ],
+      [ "--includeDisabled",          "-z",    GetoptLong::NO_ARGUMENT ]      
     ) || usage
 
     # put the stupid crap in a hash. Much nicer to deal with.
@@ -197,10 +198,12 @@ class Input
     puts " -c    [regular|virtual|event|unknown] type of cache (| seperated)"
     puts " -j/-J [# days]         include/exclude caches placed in the last X days"
     puts " -r/-R [# days]         include/exclude caches found in the last X days"
+    puts " -z                     include disabled caches"
     puts " -n                     only include not found caches (virgins)"
     puts " -b                     only include caches with travelbugs"
     puts " -l                     set EasyName waypoint id length. (16)"
     puts " -P                     HTTP proxy server, http://username:pass@host:port/"
+    puts " -C                     Clear local browser cache"
     puts ""
     puts "::: OUTPUT FORMATS:"
     outputDetails = Output.new
@@ -395,8 +398,8 @@ class Input
         @@optHash['sizeMin'] = askFromList("What is the smallest cache you seek (#{sizes.join(', ')})?", sizes, nil)
         @@optHash['sizeMax'] = askFromList("Great! What is the largest cache you seek (#{sizes.join(', ')})?", sizes, nil)
       when '9'
-        kinds = ['traditional', 'multicache', 'event', 'unknown', 'letterbox', 'virtual']
-        @@optHash['cacheType'] = askFromList("What do you seek (seperate with commas) (#{kinds.join(', ')})?", kinds, nil)
+        kinds = ['traditional', 'multicache', 'event', 'unknown', 'letterbox', 'virtual', 'earthcache']
+        @@optHash['cacheType'] = askFromList("Valid types: #{kinds.join(', ')}\nWhat do you seek (seperate with commas)?", kinds, nil)
 
       when '10'
         answer = ask('Would you like to only include virgin geocaches (geocaches that have never been found)?', nil)
