@@ -1,4 +1,4 @@
-# $Id: details.rb 546 2010-01-25 12:49:22Z helixblue $
+# $Id: details.rb 577 2010-04-11 15:39:20Z helixblue $
 require 'lib/bishop'
 require 'time'
 
@@ -98,6 +98,7 @@ class CacheDetails
 
     # We try to download the page one more time.
     if not success
+      sleep(5)
       debug "Trying to download #{url} again."
       page.invalidate()
       page.fetch()
@@ -158,7 +159,7 @@ class CacheDetails
         @waypointHash[wid]['longdesc'] = ''
         @waypointHash[wid]['details'] = ''
 
-        if not @waypointHash[wid]['mtime']:
+        if not @waypointHash[wid]['mtime']
           @waypointHash[wid]['mdays'] = -1
           @waypointHash[wid]['mtime'] = Time.at(0)
         end
@@ -252,15 +253,6 @@ class CacheDetails
         end
       end
 
-      # pan id="ctl00_ContentBody_Hints" class="displayMe">GuERR sbhe hfr gur onpx qbbe!!</span><span id="ctl00_ContentBody_decryptHint" class="hideMe">(Decrypted Hints)</span><
-      if line =~ /class="displayMe"\>(.*?)\<\/span/
-        hint = $1.dup
-        hint.gsub!(/\<.*?\>/, '')
-        @waypointHash[wid]['hint'] = hint
-        debug "got hint: #{hint}"
-      end
-
-
       if line =~ /CacheLogs\"\>/
         debug "inspecting comments: #{line}"
         cnum = 0
@@ -304,7 +296,7 @@ class CacheDetails
           debug "comment [#{cnum}] is '#{type}' by #{name}[#{user_id}] on #{date}: #{comment}"
           comment.gsub!(/\<.*?\>/, ' ')
           date = Time.parse(date)
-          if type == 'Found it' and @waypointHash[wid]['mdays'] == -1:
+          if type == 'Found it' and @waypointHash[wid]['mdays'] == -1
             debug "Found successful comment, updating mtime to #{date}"
             @waypointHash[wid]['mtime'] = date
             @waypointHash[wid]['mdays'] = daysAgo(date)
@@ -346,6 +338,16 @@ class CacheDetails
 
     }
 
+    # <div id="div_hint" class="HalfLeft"> 
+    #         Hfntr vaunovghry cbhe har pbdhr qr tenaq ongrnh<br>"Pncfvmrq" "Hcfvqr-qbja"<br>Neoer à cebkvzvgé
+    # </div>
+    if data =~ /id="div_hint".*?\>(.*?)\<\/div/m
+      hint = $1.strip
+      hint.gsub!(/^ +/, '')
+      hint.gsub!(/[\r\n]/, '')
+      @waypointHash[wid]['hint'] = hint
+      debug "got hint: [#{hint}]"
+    end
 
     # this data is all on one line, so we should just use scan and forget reparsing.
     if (wid)
@@ -367,11 +369,13 @@ class CacheDetails
 
       @waypointHash[wid]['details'] = @waypointHash[wid]['shortdesc'] + " ... " + @waypointHash[wid]['longdesc']
 
+
+      # Parse the additional waypoints table. Needs additional work for non-HTML templates.
+      debug "will addit"
+      @waypointHash[wid]['additional_raw'] = parseAdditionalWaypoints(data)
+
     end  # end wid check.
 
-    # Parse the additional waypoints table. Needs additional work for non-HTML templates.
-    debug "will addit"
-    @waypointHash[wid]['additional_raw'] = parseAdditionalWaypoints(data)
 
 
     # How valid is this cache?
@@ -385,7 +389,7 @@ class CacheDetails
   
   def fixRelativeImageLinks(text)
     new_text = text.gsub(' src="/', ' src="http://www.geocaching.com/')
-    if text != new_text:
+    if text != new_text
       debug "fixed relative links in #{new_text}"
     end
     return new_text
@@ -406,7 +410,7 @@ class CacheDetails
     # <a href="http://s06.flagcounter.com/more/NOk"><img src= "http://s06.flagcounter.com/count/NOk/bg=E2FFC4/txt=000000/border=CCCCCC/columns=4/maxflags=32/viewers=0/labels=1/pageviews=1/" alt="free counters" /></a>
     removed = text.gsub(/\<a href.*?flagcounter.*?\<\/a\>/m, '')
     removed.gsub!(/\<\/*center\>/, '')
-    if removed != text:
+    if removed != text
       debug "Removed spam from: ----------------------------------"
       debug removed
       debug "-----------------------------------------------------"
