@@ -1,4 +1,4 @@
-# $Id: shadowget.rb 527 2010-01-24 19:26:12Z helixblue $
+# $Id: shadowget.rb 577 2010-04-11 15:39:20Z helixblue $
 
 require 'digest/md5'
 require 'net/http'
@@ -24,7 +24,7 @@ class ShadowFetch
     @localExpiry=518400    		# 6 days
     @maxFailures = 2
     @httpHeaders = {
-      'User-Agent'      => "Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.5; en-US; rv:1.9.0.1) Gecko/2008070206 Firefox/3.0.1",
+      'User-Agent'      => "Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_2; en-US) AppleWebKit/532.9 (KHTML, like Gecko) Chrome/5.0.307.11 Safari/532.9",
       'Accept'          => 'text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5',
       'Accept-Language' => 'en-us,en;q=0.5',
       'Accept-Charset'  => 'ISO-8859-1,utf-8;q=0.7,*;q=0.7'
@@ -214,7 +214,6 @@ class ShadowFetch
     
   def fetchURL (url_str, redirects=2)  # full http:// string!
     raise ArgumentError, 'HTTP redirect too deep' if redirects == 0
-        
     debug "Fetching [#{url_str}]"        
     uri = URI.parse(url_str)
     if (@@downloadErrors >= @maxFailures)
@@ -261,8 +260,13 @@ class ShadowFetch
     rescue Timeout::Error => e
       displayWarning "Timed out trying to access #{uri.host}:80"
       @@downloadErrors = @@downloadErrors + 1
-      sleep(2)
+      sleep(5)
       return fetchURL(url_str, redirects)
+    rescue Errno::ECONNREFUSED => e
+      displayWarning "Connection refused accessing #{uri.host}:80"
+      @@downloadErrors = @@downloadErrors + 1
+      sleep(5)
+      return fetchURL(url_str, redirects)      
     end
           
     case resp
