@@ -1,7 +1,7 @@
 # This is our dump templating engine. It only handles really simple text formats at the moment.
 # GeoToad 4.0 will have a plugins architecture that replaces this.
 #
-# $Id: templates.rb 545 2010-01-25 12:39:28Z helixblue $
+# $Id: templates.rb 575 2010-04-11 14:43:11Z helixblue $
 
 $Format = {
   'gpspoint'    => {
@@ -143,10 +143,10 @@ N|O|P|Q|R|S|T|U|V|W|X|Y|Z</pre></font><br>",
     'desc'    => 'CSV for spreadsheet imports',
     'spacer'    => "",
     'templatePre' => "\"Name\",\"Waypoint ID\",\"Creator\",\"Difficulty\",\"Terrain\"," +
-      "\"Latitude\",\"Longitude\",\"Type\",\"Creation Date\",\"Details\"\r\n",
+      "\"Latitude\",\"Longitude\",\"Type\",\"Size\",\"Creation Date\",\"Details\"\r\n",
     'templateWP'    => "\"<%wp.name%>\",\"<%out.wid%>\",\"<%wp.creator%>\"," +
       "<%wp.difficulty%>,<%wp.terrain%>,\"<%wp.latwritten%>\",\"<%wp.lonwritten%>\"," +
-      "\"<%wp.type%>\",\"<%out.cdate%>\",\"<%outText.details%>\"\r\n"
+      "\"<%wp.type%>\",\"<%wp.size%>\",\"<%out.cdate%>\",\"<%outText.details%>\"\r\n"
   },
 
   'vcf'    => {
